@@ -22,10 +22,11 @@ from .Group import Group
 from .Header import Header
 from .Image import Image
 from .InputWrapper import InputWrapper
+from .MantineProvider import MantineProvider
 from .Modal import Modal
 from .MultiSelect import MultiSelect
 from .Navbar import Navbar
-from .NotificationHandler import NotificationHandler
+from .Notification import Notification
 from .NotificationsProvider import NotificationsProvider
 from .Paper import Paper
 from .Prism import Prism
@@ -73,10 +74,11 @@ __all__ = [
     "Header",
     "Image",
     "InputWrapper",
+    "MantineProvider",
     "Modal",
     "MultiSelect",
     "Navbar",
-    "NotificationHandler",
+    "Notification",
     "NotificationsProvider",
     "Paper",
     "Prism",
